# Genesis 4 Output

::: genesis.version4.Genesis4Output

::: genesis.version4.output.Genesis4Output

## Shared output information

::: genesis.version4.output._OutputBase

## Run and general information

::: genesis.version4.output.RunInfo
::: genesis.version4.output.OutputGlobal

## Field information

::: genesis.version4.output.FieldFile
::: genesis.version4.output.OutputFieldStat
::: genesis.version4.output.OutputFieldGlobal
::: genesis.version4.output.OutputField

## Lattice information
::: genesis.version4.output.OutputLattice

## Beam information
::: genesis.version4.output.OutputBeamStat
::: genesis.version4.output.OutputBeamGlobal
::: genesis.version4.output.OutputBeam

## Metadata
::: genesis.version4.output.OutputMetaDumps
::: genesis.version4.output.OutputMetaVersion
::: genesis.version4.output.OutputMeta
